CheckBox
================================

.. currentmodule:: enaml.widgets.check_box

.. autoclass:: CheckBox


Backends
--------

Qt
^^

.. inheritance-diagram::
    enaml.widgets.qt.qt_check_box.QtCheckBox
    :parts: 1

.. autoclass:: enaml.widgets.qt.qt_check_box.QtCheckBox

Wx
^^

.. inheritance-diagram::
    enaml.widgets.wx.wx_check_box.WXCheckBox
    :parts: 1

.. autoclass:: enaml.widgets.wx.wx_check_box.WXCheckBox
